vim.cmd("highlight clear")
vim.o.background = "dark"
vim.o.termguicolors = true
vim.g.colors_name = "monokai"

local c = {
	base0 = "#222426",
	base1 = "#272a30",
	base2 = "#26292C",
	base3 = "#2E323C",
	base4 = "#333842",
	base5 = "#4d5154",
	base6 = "#9ca0a4",
	base7 = "#b1b1b1",
	base8 = "#e3e3e1",
	border = "#a1b5b1",
	brown = "#504945",
	white = "#f8f8f0",
	grey = "#8F908A",
	black = "#000000",
	pink = "#f92672",
	green = "#a6e22e",
	aqua = "#66d9ef",
	yellow = "#e6db74",
	orange = "#fd971f",
	purple = "#ae81ff",
	red = "#e95678",
	diff_add = "#3d5213",
	diff_remove = "#4a0f23",
	diff_change = "#27406b",
	diff_text = "#23324d",
}

local hl = function(group, opts)
	vim.api.nvim_set_hl(0, group, opts)
end

-- Syntax
hl("Normal", { fg = c.white, bg = c.base2 })
hl("NormalFloat", { bg = c.base1 })
hl("Pmenu", { fg = c.white, bg = c.base3 })
hl("PmenuSel", { fg = c.base4, bg = c.orange })
hl("PmenuSelBold", { fg = c.base4, bg = c.orange })
hl("PmenuThumb", { fg = c.purple, bg = c.green })
hl("PmenuSbar", { bg = c.base3 })
hl("Cursor", { reverse = true })
hl("ColorColumn", { bg = c.base3 })
hl("CursorLine", { bg = c.base3 })
hl("NonText", { fg = c.base5 })
hl("Visual", { bg = c.base4 })
hl("VisualNOS", { bg = c.base3 })
hl("Search", { fg = c.base2, bg = c.yellow })
hl("IncSearch", { fg = c.base2, bg = c.orange })
hl("CursorLineNr", { fg = c.orange, bg = c.base2 })
hl("MatchParen", { fg = c.pink })
hl("Question", { fg = c.yellow })
hl("ModeMsg", { fg = c.white, bold = true })
hl("MoreMsg", { fg = c.white, bold = true })
hl("ErrorMsg", { fg = c.red, bold = true })
hl("WarningMsg", { fg = c.yellow, bold = true })
hl("VertSplit", { fg = c.brown })
hl("LineNr", { fg = c.base5, bg = c.base2 })
hl("SignColumn", { fg = c.white, bg = c.base2 })
hl("StatusLine", { fg = c.base7, bg = c.base3 })
hl("StatusLineNC", { fg = c.grey, bg = c.base3 })
hl("Tabline", {})
hl("TabLineFill", {})
hl("TabLineSel", { bg = c.base4 })
hl("SpellBad", { fg = c.red, undercurl = true })
hl("SpellCap", { fg = c.purple, undercurl = true })
hl("SpellRare", { fg = c.aqua, undercurl = true })
hl("SpellLocal", { fg = c.pink, undercurl = true })
hl("SpecialKey", { fg = c.pink })
hl("Title", { fg = c.yellow, bold = true })
hl("Directory", { fg = c.aqua })
hl("DiffAdd", { bg = c.diff_add })
hl("DiffDelete", { bg = c.diff_remove })
hl("DiffChange", { bg = c.diff_change })
hl("DiffText", { bg = c.diff_text })
hl("diffAdded", { fg = c.green })
hl("diffRemoved", { fg = c.pink })
hl("Folded", { fg = c.grey, bg = c.base3 })
hl("FoldColumn", { fg = c.white, bg = c.black })
hl("Constant", { fg = c.aqua })
hl("Number", { fg = c.purple })
hl("Float", { fg = c.purple })
hl("Boolean", { fg = c.purple })
hl("Character", { fg = c.yellow })
hl("String", { fg = c.yellow })
hl("Type", { fg = c.aqua })
hl("Structure", { fg = c.aqua })
hl("StorageClass", { fg = c.aqua })
hl("Typedef", { fg = c.aqua })
hl("Identifier", { fg = c.white })
hl("Function", { fg = c.green, italic = true })
hl("Statement", { fg = c.pink })
hl("Operator", { fg = c.pink })
hl("Label", { fg = c.pink })
hl("Keyword", { fg = c.pink, italic = true })
hl("PreProc", { fg = c.green })
hl("Include", { fg = c.aqua, italic = true })
hl("Define", { fg = c.pink })
hl("Macro", { fg = c.pink })
hl("PreCondit", { fg = c.pink })
hl("Special", { fg = c.white })
hl("SpecialChar", { fg = c.pink })
hl("Delimiter", { fg = c.white })
hl("SpecialComment", { fg = c.grey, italic = true })
hl("Tag", { fg = c.orange })
hl("Todo", { fg = c.orange })
hl("Comment", { fg = c.base6, italic = true })
hl("Underlined", { underline = true })
hl("Ignore", {})
hl("Error", { fg = c.red })
hl("Terminal", { fg = c.white, bg = c.base2 })
hl("EndOfBuffer", { fg = c.base2 })
hl("Conceal", { fg = c.grey })
hl("vCursor", { reverse = true })
hl("iCursor", { reverse = true })
hl("lCursor", { reverse = true })
hl("CursorIM", { reverse = true })
hl("CursorColumn", { bg = c.base3 })
hl("Whitespace", { fg = c.base5 })
hl("WildMenu", { fg = c.white, bg = c.orange })
hl("QuickFixLine", { fg = c.purple, bold = true })
hl("Debug", { fg = c.orange })
hl("debugBreakpoint", { fg = c.base2, bg = c.red })
hl("Conditional", { fg = c.pink })
hl("Repeat", { fg = c.pink })
hl("Exception", { fg = c.pink })

-- Plugins
--hl("@annotation", { fg = c.green })
--hl("@attribute", { fg = c.green })
--hl("@boolean", { fg = c.purple })
--hl("@character", { fg = c.yellow })
--hl("@character.special", { fg = c.purple })
--hl("@comment", { fg = c.base6, italic = true })
--hl("@conceal", { fg = c.grey })
--hl("@conditional", { fg = c.pink })
--hl("@conditional.ternary", { fg = c.pink })
--hl("@constant", { fg = c.aqua })
--hl("@constant.builtin", { fg = c.purple })
--hl("@constant.macro", { fg = c.purple })
--hl("@constructor", { fg = c.aqua })
--hl("@debug", { fg = c.pink })
--hl("@define", { fg = c.aqua })
--hl("@definition", { fg = c.green })
--hl("@definition.associated", { fg = c.green })
--hl("@definition.constant", { fg = c.green })
--hl("@definition.enum", { fg = c.green })
--hl("@definition.field", { fg = c.green })
--hl("@definition.function", { fg = c.green })
--hl("@definition.import", { fg = c.white })
--hl("@definition.macro", { fg = c.green, italic = true })
--hl("@definition.method", { fg = c.green })
--hl("@definition.namespace", { fg = c.white })
--hl("@definition.parameter", { fg = c.orange })
--hl("@definition.type", { fg = c.green })
--hl("@definition.var", { fg = c.green })
--hl("@error", { fg = c.red })
--hl("@exception", { fg = c.pink })
--hl("@field", { fg = c.white })
--hl("@float", { fg = c.purple })
--hl("@function", { fg = c.green, italic = true })
--hl("@function.builtin", { fg = c.aqua })
--hl("@function.call", { fg = c.white })
--hl("@function.macro", { fg = c.green, italic = true })
--hl("@include", { fg = c.aqua, italic = true })
--hl("@keyword", { fg = c.pink, italic = true })
--hl("@keyword.function", { fg = c.aqua, italic = true })
--hl("@keyword.operator", { fg = c.pink })
--hl("@keyword.return", { fg = c.pink })
--hl("@label", { fg = c.pink })
--hl("@math", { fg = c.yellow })
--hl("@method", { fg = c.green })
--hl("@method.call", { fg = c.white })
--hl("@namespace", { fg = c.purple })
--hl("@number", { fg = c.purple })
--hl("@operator", { fg = c.pink })
--hl("@parameter", { fg = c.orange })
--hl("@parameter.reference", { fg = c.white })
--hl("@preproc", { fg = c.green })
--hl("@property", { fg = c.white })
--hl("@punctuation.bracket", { fg = c.white })
--hl("@punctuation.delimiter", { fg = c.white })
--hl("@punctuation.special", { fg = c.pink })
--hl("@reference", { fg = c.white })
--hl("@repeat", { fg = c.pink })
--hl("@scope", { fg = c.white })
--hl("@storageclass", { fg = c.aqua })
--hl("@storageclass.lifetime", { fg = c.aqua })
--hl("@strike", { fg = c.grey })
--hl("@string", { fg = c.yellow })
--hl("@string.escape", { fg = c.purple })
--hl("@string.regex", { fg = c.purple })
--hl("@string.special", { fg = c.purple })
--hl("@symbol", { fg = c.purple })
--hl("@tag", { fg = c.pink })
--hl("@tag.attribute", { fg = c.green })
--hl("@tag.delimiter", { fg = c.white })
--hl("@text", { fg = c.green })
--hl("@text.danger", { fg = c.red, bold = true })
--hl("@text.diff.add", { fg = c.diff_add })
--hl("@text.diff.delete", { fg = c.diff_remove })
--hl("@text.emphasis", { bold = true })
--hl("@text.environment", { fg = c.purple })
--hl("@text.environment.name", { fg = c.aqua })
--hl("@text.literal", { fg = c.yellow })
--hl("@text.math", { fg = c.yellow })
--hl("@text.note", { fg = c.aqua, bold = true })
--hl("@text.quote", { fg = c.grey })
--hl("@text.reference", { fg = c.orange, italic = true })
--hl("@text.strike", { fg = c.grey })
--hl("@text.strong", { bold = true })
--hl("@text.title", { fg = c.yellow, bold = true })
--hl("@text.todo", { fg = c.aqua })
--hl("@text.underline", { underline = true })
--hl("@text.uri", { fg = c.aqua, underline = true })
--hl("@text.warning", { fg = c.yellow, bold = true })
--hl("@todo", { fg = c.aqua })
--hl("@type", { fg = c.aqua })
--hl("@type.builtin", { fg = c.aqua })
--hl("@type.definition", { fg = c.aqua })
--hl("@type.qualifier", { fg = c.pink })
--hl("@uri", { fg = c.aqua, underline = true })
--hl("@variable", { fg = c.white })
--hl("@variable.builtin", { fg = c.orange })
--hl("dbui_tables", { fg = c.white })
--hl("DiagnosticSignError", { fg = c.red })
--hl("DiagnosticSignWarn", { fg = c.yellow })
--hl("DiagnosticSignInfo", { fg = c.white })
--hl("DiagnosticSignHint", { fg = c.aqua })
--hl("DiagnosticVirtualTextError", { fg = c.red })
--hl("DiagnosticVirtualTextWarn", { fg = c.yellow })
--hl("DiagnosticVirtualTextInfo", { fg = c.white })
--hl("DiagnosticVirtualTextHint", { fg = c.aqua })
--hl("DiagnosticUnderlineError", { undercurl = true, sp = c.red })
--hl("DiagnosticUnderlineWarn", { undercurl = true, sp = c.yellow })
--hl("DiagnosticUnderlineInfo", { undercurl = true, sp = c.white })
--hl("DiagnosticUnderlineHint", { undercurl = true, sp = c.aqua })
--hl("CursorWord0", { bg = c.white, fg = c.black })
--hl("CursorWord1", { bg = c.white, fg = c.black })
--hl("NvimTreeFolderName", { fg = c.white })
--hl("NvimTreeRootFolder", { fg = c.pink })
--hl("NvimTreeSpecialFile", { fg = c.white })